@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-categories
 r"""
 Groups
 """
@@ -42,7 +43,7 @@ class Groups(CategoryWithAxiom):
         """
         EXAMPLES::
 
-            sage: Groups().example()                                                    # optional - sage.groups
+            sage: Groups().example()                                                    # needs sage.modules
             General Linear Group of degree 4 over Rational Field
         """
         from sage.rings.rational_field import QQ
@@ -59,7 +60,7 @@ class Groups(CategoryWithAxiom):
         - ``index_set`` -- (optional) an index set for the generators; if
           an integer, then this represents `\{0, 1, \ldots, n-1\}`
 
-        - ``names`` -- a string or list/tuple/iterable of strings
+        - ``names`` -- string or list/tuple/iterable of strings
           (default: ``'x'``); the generator names or name prefix
 
         When the index set is an integer or only variable names are given,
@@ -69,13 +70,14 @@ class Groups(CategoryWithAxiom):
 
         EXAMPLES::
 
-            sage: Groups.free(index_set=ZZ)                                             # optional - sage.groups
+            sage: # needs sage.combinat sage.groups
+            sage: Groups.free(index_set=ZZ)
             Free group indexed by Integer Ring
-            sage: Groups().free(ZZ)                                                     # optional - sage.groups
+            sage: Groups().free(ZZ)
             Free group indexed by Integer Ring
-            sage: Groups().free(5)                                                      # optional - sage.groups
+            sage: Groups().free(5)
             Free Group on generators {x0, x1, x2, x3, x4}
-            sage: F.<x,y,z> = Groups().free(); F                                        # optional - sage.groups
+            sage: F.<x,y,z> = Groups().free(); F
             Free Group on generators {x, y, z}
         """
         from sage.rings.integer_ring import ZZ
@@ -99,9 +101,9 @@ class Groups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: A = AlternatingGroup(4)                                           # optional - sage.groups
-                sage: A.group_generators()                                              # optional - sage.groups
-                Family ((2,3,4), (1,2,3))
+                sage: A = AlternatingGroup(4)                                           # needs sage.groups
+                sage: A.group_generators()                                              # needs sage.groups
+                Family ((1,2,3), (2,3,4))
             """
             from sage.sets.family import Family
             try:
@@ -120,11 +122,12 @@ class Groups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: A = AlternatingGroup(4)                                           # optional - sage.groups
-                sage: A.monoid_generators()                                             # optional - sage.groups
-                Family ((2,3,4), (1,2,3))
-                sage: F.<x,y> = FreeGroup()                                             # optional - sage.groups
-                sage: F.monoid_generators()                                             # optional - sage.groups
+                sage: # needs sage.groups
+                sage: A = AlternatingGroup(4)
+                sage: A.monoid_generators()
+                Family ((1,2,3), (2,3,4))
+                sage: F.<x,y> = FreeGroup()
+                sage: F.monoid_generators()
                 Family (x, y, x^-1, y^-1)
             """
             G = self.group_generators()
@@ -142,8 +145,8 @@ class Groups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: G = SymmetricGroup(3)                                             # optional - sage.groups
-                sage: G._test_inverse()                                                 # optional - sage.groups
+                sage: G = SymmetricGroup(3)                                             # needs sage.groups
+                sage: G._test_inverse()                                                 # needs sage.groups
             """
             tester = self._tester(**options)
             for x in tester.some_elements():
@@ -152,12 +155,12 @@ class Groups(CategoryWithAxiom):
 
         def semidirect_product(self, N, mapping, check=True):
             r"""
-            The semi-direct product of two groups
+            The semi-direct product of two groups.
 
             EXAMPLES::
 
-                sage: G = Groups().example()                                            # optional - sage.groups
-                sage: G.semidirect_product(G, Morphism(G, G))                           # optional - sage.groups
+                sage: G = Groups().example()                                            # needs sage.modules
+                sage: G.semidirect_product(G, Morphism(G, G))                           # needs sage.modules
                 Traceback (most recent call last):
                 ...
                 NotImplementedError: semidirect product of General Linear Group of degree 4
@@ -168,7 +171,7 @@ class Groups(CategoryWithAxiom):
 
         def holomorph(self):
             r"""
-            The holomorph of a group
+            The holomorph of a group.
 
             The holomorph of a group `G` is the semidirect product
             `G \rtimes_{id} Aut(G)`, where `id` is the identity function
@@ -178,21 +181,21 @@ class Groups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: G = Groups().example()                                            # optional - sage.groups
-                sage: G.holomorph()                                                     # optional - sage.groups
+                sage: G = Groups().example()                                            # needs sage.modules
+                sage: G.holomorph()                                                     # needs sage.modules
                 Traceback (most recent call last):
                 ...
                 NotImplementedError: holomorph of General Linear Group of degree 4
                 over Rational Field not yet implemented
             """
-            raise NotImplementedError("holomorph of %s not yet implemented"%self)
+            raise NotImplementedError("holomorph of %s not yet implemented" % self)
 
         def cayley_table(self, names='letters', elements=None):
             r"""
             Return the "multiplication" table of this multiplicative group,
             which is also known as the "Cayley table".
 
-            .. note:: The order of the elements in the row and column
+            .. NOTE:: The order of the elements in the row and column
               headings is equal to the order given by the table's
               :meth:`~sage.matrix.operation_table.OperationTable.column_keys`
               method.  The association between the actual elements and the
@@ -207,22 +210,22 @@ class Groups(CategoryWithAxiom):
 
             INPUT:
 
-            - ``names`` - the type of names used, values are:
+            - ``names`` -- the type of names used, values are:
 
-              * ``'letters'`` - lowercase ASCII letters are used
+              * ``'letters'`` -- lowercase ASCII letters are used
                 for a base 26 representation of the elements'
                 positions in the list given by :meth:`list`,
                 padded to a common width with leading 'a's.
-              * ``'digits'`` - base 10 representation of the
+              * ``'digits'`` -- base 10 representation of the
                 elements' positions in the list given by
                 :meth:`~sage.matrix.operation_table.OperationTable.column_keys`,
                 padded to a common width with leading zeros.
-              * ``'elements'`` - the string representations
+              * ``'elements'`` -- the string representations
                 of the elements themselves.
               * a list - a list of strings, where the length
                 of the list equals the number of elements.
 
-            - ``elements`` - default = ``None``.  A list of
+            - ``elements`` -- (default: ``None``) a list of
               elements of the group, in forms that can be
               coerced into the structure, eg. their string
               representations. This may be used to impose an
@@ -246,11 +249,12 @@ class Groups(CategoryWithAxiom):
             Permutation groups, matrix groups and abelian groups
             can all compute their multiplication tables.  ::
 
-                sage: G = DiCyclicGroup(3)                                              # optional - sage.groups
-                sage: T = G.cayley_table()                                              # optional - sage.groups
-                sage: T.column_keys()                                                   # optional - sage.groups
+                sage: # needs sage.groups
+                sage: G = DiCyclicGroup(3)
+                sage: T = G.cayley_table()
+                sage: T.column_keys()
                 ((), (5,6,7), ..., (1,4,2,3)(5,7))
-                sage: T                                                                 # optional - sage.groups
+                sage: T
                 *  a b c d e f g h i j k l
                  +------------------------
                 a| a b c d e f g h i j k l
@@ -268,8 +272,8 @@ class Groups(CategoryWithAxiom):
 
             ::
 
-                sage: M = SL(2, 2)                                                      # optional - sage.groups
-                sage: M.cayley_table()                                                  # optional - sage.groups
+                sage: M = SL(2, 2)                                                      # needs sage.modules
+                sage: M.cayley_table()                                                  # needs sage.libs.gap sage.modules
                 *  a b c d e f
                  +------------
                 a| a b c d e f
@@ -282,8 +286,8 @@ class Groups(CategoryWithAxiom):
 
             ::
 
-                sage: A = AbelianGroup([2, 3])                                          # optional - sage.groups
-                sage: A.cayley_table()                                                  # optional - sage.groups
+                sage: A = AbelianGroup([2, 3])                                          # needs sage.groups
+                sage: A.cayley_table()                                                  # needs sage.groups
                 *  a b c d e f
                  +------------
                 a| a b c d e f
@@ -301,8 +305,8 @@ class Groups(CategoryWithAxiom):
             you can choose to just use the string representations
             of the elements themselves.  ::
 
-                sage: C = CyclicPermutationGroup(11)                                    # optional - sage.groups
-                sage: C.cayley_table(names='digits')                                    # optional - sage.groups
+                sage: C = CyclicPermutationGroup(11)                                    # needs sage.groups
+                sage: C.cayley_table(names='digits')                                    # needs sage.groups
                  *  00 01 02 03 04 05 06 07 08 09 10
                   +---------------------------------
                 00| 00 01 02 03 04 05 06 07 08 09 10
@@ -319,9 +323,9 @@ class Groups(CategoryWithAxiom):
 
             ::
 
-                sage: G = QuaternionGroup()                                             # optional - sage.groups
-                sage: names = ['1', 'I', '-1', '-I', 'J', '-K', '-J', 'K']              # optional - sage.groups
-                sage: G.cayley_table(names=names)                                       # optional - sage.groups
+                sage: G = QuaternionGroup()                                             # needs sage.groups
+                sage: names = ['1', 'I', '-1', '-I', 'J', '-K', '-J', 'K']
+                sage: G.cayley_table(names=names)                                       # needs sage.groups
                  *   1  I -1 -I  J -K -J  K
                   +------------------------
                  1|  1  I -1 -I  J -K -J  K
@@ -335,8 +339,8 @@ class Groups(CategoryWithAxiom):
 
             ::
 
-                sage: A = AbelianGroup([2, 2])                                          # optional - sage.groups
-                sage: A.cayley_table(names='elements')                                  # optional - sage.groups
+                sage: A = AbelianGroup([2, 2])                                          # needs sage.groups
+                sage: A.cayley_table(names='elements')                                  # needs sage.groups
                     *      1    f1    f0 f0*f1
                      +------------------------
                     1|     1    f1    f0 f0*f1
@@ -348,10 +352,11 @@ class Groups(CategoryWithAxiom):
             routine behaves similarly, but changes an existing table "in-place."
             ::
 
-                sage: G = AlternatingGroup(3)                                           # optional - sage.groups
-                sage: T = G.cayley_table()                                              # optional - sage.groups
-                sage: T.change_names('digits')                                          # optional - sage.groups
-                sage: T                                                                 # optional - sage.groups
+                sage: # needs sage.groups
+                sage: G = AlternatingGroup(3)
+                sage: T = G.cayley_table()
+                sage: T.change_names('digits')
+                sage: T
                 *  0 1 2
                  +------
                 0| 0 1 2
@@ -363,11 +368,11 @@ class Groups(CategoryWithAxiom):
             Elements will be coerced into the group as part of setting
             up the table.  ::
 
-                sage: G = SL(2,ZZ)                                                      # optional - sage.groups
-                sage: G                                                                 # optional - sage.groups
+                sage: # needs sage.modules
+                sage: G = SL(2,ZZ); G
                 Special Linear Group of degree 2 over Integer Ring
-                sage: identity = matrix(ZZ, [[1,0], [0,1]])                             # optional - sage.groups
-                sage: G.cayley_table(elements=[identity, -identity])                    # optional - sage.groups
+                sage: identity = matrix(ZZ, [[1,0], [0,1]])
+                sage: G.cayley_table(elements=[identity, -identity])
                 *  a b
                  +----
                 a| a b
@@ -384,11 +389,11 @@ class Groups(CategoryWithAxiom):
             confirms that they form a closed subset in the group.
             ::
 
-                sage: from sage.matrix.operation_table import OperationTable            # optional - sage.groups
-                sage: G = DiCyclicGroup(3)                                              # optional - sage.groups
-                sage: commutator = lambda x, y: x*y*x^-1*y^-1                           # optional - sage.groups
-                sage: T = OperationTable(G, commutator)                                 # optional - sage.groups
-                sage: T                                                                 # optional - sage.groups
+                sage: # needs sage.groups sage.modules
+                sage: from sage.matrix.operation_table import OperationTable
+                sage: G = DiCyclicGroup(3)
+                sage: commutator = lambda x, y: x*y*x^-1*y^-1
+                sage: T = OperationTable(G, commutator); T
                 .  a b c d e f g h i j k l
                  +------------------------
                 a| a a a a a a a a a a a a
@@ -403,13 +408,12 @@ class Groups(CategoryWithAxiom):
                 j| a b c a b c a c b a c b
                 k| a b c a b c b a c b a c
                 l| a b c a b c c b a c b a
-
-                sage: trans = T.translation()                                           # optional - sage.groups
-                sage: comm = [trans['a'], trans['b'], trans['c']]                       # optional - sage.groups
-                sage: comm                                                              # optional - sage.groups
+                sage: trans = T.translation()
+                sage: comm = [trans['a'], trans['b'], trans['c']]
+                sage: comm
                 [(), (5,6,7), (5,7,6)]
-                sage: P = G.cayley_table(elements=comm)                                 # optional - sage.groups
-                sage: P                                                                 # optional - sage.groups
+                sage: P = G.cayley_table(elements=comm)
+                sage: P
                 *  a b c
                  +------
                 a| a b c
@@ -421,12 +425,11 @@ class Groups(CategoryWithAxiom):
                 Arrange an ordering of elements into cosets of a normal
                 subgroup close to size `\sqrt{n}`.  Then the quotient
                 group structure is often apparent in the table.  See
-                comments on :trac:`7555`.
+                comments on :issue:`7555`.
 
             AUTHOR:
 
             - Rob Beezer (2010-03-15)
-
             """
             from sage.matrix.operation_table import OperationTable
             import operator
@@ -440,9 +443,9 @@ class Groups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: A = AbelianGroup([2, 2])                                          # optional - sage.groups
-                sage: c = A.conjugacy_class(A.an_element())                             # optional - sage.groups
-                sage: type(c)                                                           # optional - sage.groups
+                sage: A = AbelianGroup([2, 2])                                          # needs sage.groups
+                sage: c = A.conjugacy_class(A.an_element())                             # needs sage.groups
+                sage: type(c)                                                           # needs sage.groups
                 <class 'sage.groups.conjugacy_classes.ConjugacyClass_with_category'>
             """
             from sage.groups.conjugacy_classes import ConjugacyClass
@@ -455,16 +458,16 @@ class Groups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: D = DihedralGroup(5)                                              # optional - sage.groups
-                sage: g = D((1,3,5,2,4))                                                # optional - sage.groups
-                sage: g.conjugacy_class()                                               # optional - sage.groups
+                sage: D = DihedralGroup(5)                                              # needs sage.groups
+                sage: g = D((1,3,5,2,4))                                                # needs sage.groups
+                sage: g.conjugacy_class()                                               # needs sage.groups
                 Conjugacy class of (1,3,5,2,4)
                  in Dihedral group of order 10 as a permutation group
 
-                sage: H = MatrixGroup([matrix(GF(5), 2, [1,2, -1,1]),                   # optional - sage.groups sage.rings.finite_rings sage.modules
+                sage: H = MatrixGroup([matrix(GF(5), 2, [1,2, -1,1]),                   # needs sage.modules
                 ....:                  matrix(GF(5), 2, [1,1, 0,1])])
-                sage: h = H(matrix(GF(5), 2, [1,2, -1,1]))                              # optional - sage.groups sage.rings.finite_rings sage.modules
-                sage: h.conjugacy_class()                                               # optional - sage.groups sage.rings.finite_rings sage.modules
+                sage: h = H(matrix(GF(5), 2, [1,2, -1,1]))                              # needs sage.modules
+                sage: h.conjugacy_class()                                               # needs sage.groups sage.modules
                 Conjugacy class of [1 2]
                                    [4 1]
                 in Matrix group over Finite Field of size 5 with 2 generators (
@@ -472,15 +475,15 @@ class Groups(CategoryWithAxiom):
                 [4 1], [0 1]
                 )
 
-                sage: G = SL(2, GF(2))                                                  # optional - sage.groups sage.rings.finite_rings sage.modules
-                sage: g = G.gens()[0]                                                   # optional - sage.groups sage.rings.finite_rings sage.modules
-                sage: g.conjugacy_class()                                               # optional - sage.groups sage.rings.finite_rings sage.modules
+                sage: G = SL(2, GF(2))                                                  # needs sage.modules
+                sage: g = G.gens()[0]                                                   # needs sage.groups sage.modules
+                sage: g.conjugacy_class()                                               # needs sage.groups sage.modules
                 Conjugacy class of [1 1]
                 [0 1] in Special Linear Group of degree 2 over Finite Field of size 2
 
-                sage: G = SL(2, QQ)                                                     # optional - sage.groups sage.modules
-                sage: g = G([[1,1], [0,1]])                                             # optional - sage.groups sage.modules
-                sage: g.conjugacy_class()                                               # optional - sage.groups sage.modules
+                sage: G = SL(2, QQ)                                                     # needs sage.modules
+                sage: g = G([[1,1], [0,1]])                                             # needs sage.modules
+                sage: g.conjugacy_class()                                               # needs sage.groups sage.modules
                 Conjugacy class of [1 1]
                 [0 1] in Special Linear Group of degree 2 over Rational Field
             """
@@ -506,18 +509,19 @@ class Groups(CategoryWithAxiom):
             - ``index_set`` -- (optional) an index set for the generators; if
               an integer, then this represents `\{0, 1, \ldots, n-1\}`
 
-            - ``names`` -- a string or list/tuple/iterable of strings
+            - ``names`` -- string or list/tuple/iterable of strings
               (default: ``'x'``); the generator names or name prefix
 
             EXAMPLES::
 
-                sage: Groups.Commutative.free(index_set=ZZ)                             # optional - sage.groups
+                sage: # needs sage.combinat sage.groups
+                sage: Groups.Commutative.free(index_set=ZZ)
                 Free abelian group indexed by Integer Ring
-                sage: Groups().Commutative().free(ZZ)                                   # optional - sage.groups
+                sage: Groups().Commutative().free(ZZ)
                 Free abelian group indexed by Integer Ring
-                sage: Groups().Commutative().free(5)                                    # optional - sage.groups
+                sage: Groups().Commutative().free(5)
                 Multiplicative Abelian group isomorphic to Z x Z x Z x Z x Z
-                sage: F.<x,y,z> = Groups().Commutative().free(); F                      # optional - sage.groups
+                sage: F.<x,y,z> = Groups().Commutative().free(); F
                 Multiplicative Abelian group isomorphic to Z x Z x Z
             """
             from sage.rings.integer_ring import ZZ
@@ -574,28 +578,30 @@ class Groups(CategoryWithAxiom):
 
                 EXAMPLES::
 
-                    sage: C5 = CyclicPermutationGroup(5)                                # optional - sage.groups
-                    sage: C4 = CyclicPermutationGroup(4)                                # optional - sage.groups
-                    sage: S4 = SymmetricGroup(3)                                        # optional - sage.groups
-                    sage: C = cartesian_product([C5, C4, S4])                           # optional - sage.groups
-                    sage: C.group_generators()                                          # optional - sage.groups
+                    sage: # needs sage.groups
+                    sage: C5 = CyclicPermutationGroup(5)
+                    sage: C4 = CyclicPermutationGroup(4)
+                    sage: S4 = SymmetricGroup(3)
+                    sage: C = cartesian_product([C5, C4, S4])
+                    sage: C.group_generators()
                     Family (((1,2,3,4,5), (), ()),
                             ((), (1,2,3,4), ()),
                             ((), (), (1,2)),
                             ((), (), (2,3)))
 
-                We check the other portion of :trac:`16718` is fixed::
+                We check the other portion of :issue:`16718` is fixed::
 
-                    sage: len(C.j_classes())                                            # optional - sage.groups
+                    sage: len(C.j_classes())                                            # needs sage.graphs sage.groups
                     1
 
                 An example with an infinitely generated group (a better output
                 is needed)::
 
-                    sage: G = Groups.free([1,2])                                        # optional - sage.groups
-                    sage: H = Groups.free(ZZ)                                           # optional - sage.groups
-                    sage: C = cartesian_product([G, H])                                 # optional - sage.groups
-                    sage: C.monoid_generators()                                         # optional - sage.groups
+                    sage: # needs sage.combinat sage.groups
+                    sage: G = Groups.free([1,2])
+                    sage: H = Groups.free(ZZ)
+                    sage: C = cartesian_product([G, H])
+                    sage: C.monoid_generators()
                     Lazy family (gen(i))_{i in The Cartesian product of (...)}
                 """
                 F = self.cartesian_factors()
@@ -620,21 +626,21 @@ class Groups(CategoryWithAxiom):
                 gens_prod = cartesian_product([Family(G.group_generators(),
                                                       lambda g: (i, g))
                                                for i, G in enumerate(F)])
-                return Family(gens_prod, lift, name="gen")
+                return Family(gens_prod, lift, name='gen')
 
             def order(self):
                 r"""
-                Return the cardinality of self.
+                Return the cardinality of ``self``.
 
                 EXAMPLES::
 
-                    sage: C = cartesian_product([SymmetricGroup(10), SL(2, GF(3))])     # optional - sage.groups sage.rings.finite_rings
-                    sage: C.order()                                                     # optional - sage.groups sage.rings.finite_rings
+                    sage: C = cartesian_product([SymmetricGroup(10), SL(2, GF(3))])     # needs sage.groups sage.modules
+                    sage: C.order()                                                     # needs sage.groups sage.modules
                     87091200
 
                 TESTS::
 
-                    sage: C.order.__module__                                            # optional - sage.groups sage.rings.finite_rings
+                    sage: C.order.__module__                                            # needs sage.groups sage.modules
                     'sage.categories.groups'
 
                 .. TODO::
