@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.combinat sage.modules
 r"""
 Induced Crystals
 
@@ -46,8 +47,8 @@ class InducedCrystal(UniqueRepresentation, Parent):
     - ``X`` -- the base set
     - ``phi`` -- the map `\Phi`
     - ``inverse`` -- (optional) the inverse map `\Phi^{-1}`
-    - ``from_crystal`` -- (default: ``False``) if the induced structure is
-      of the second type `\Phi : C \to X`
+    - ``from_crystal`` -- boolean (default: ``False``); if the induced
+      structure is of the second type `\Phi : C \to X`
 
     EXAMPLES:
 
