@@ -32,14 +32,15 @@ REFERENCES:
 #                  https://www.gnu.org/licenses/
 #******************************************************************************
 
-from sage.structure.category_object import CategoryObject
-from sage.categories.vector_bundles import VectorBundles
-from sage.structure.unique_representation import UniqueRepresentation
 import sage.rings.abc
-from sage.rings.cc import CC
-from sage.rings.real_mpfr import RR
-from sage.rings.integer import Integer
+from sage.categories.vector_bundles import VectorBundles
 from sage.manifolds.vector_bundle_fiber import VectorBundleFiber
+from sage.rings.cc import CC
+from sage.rings.integer import Integer
+from sage.rings.real_mpfr import RR
+from sage.structure.category_object import CategoryObject
+from sage.structure.unique_representation import UniqueRepresentation
+
 
 class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
     r"""
@@ -188,7 +189,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
          the real vector bundle E of rank 2
         sage: s in E.section_module()
         True
-
     """
     def __init__(self, rank, name, base_space, field='real',
                  latex_name=None, category=None, unique_tag=None):
@@ -202,7 +202,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: TopologicalVectorBundle(2, 'E', M)
             Topological real vector bundle E -> M of rank 2 over the base space
              2-dimensional topological manifold M
-
         """
         if base_space is None:
             raise ValueError("a base space must be provided")
@@ -265,7 +264,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: M = Manifold(2, 'M', structure='topological')
             sage: E = M.vector_bundle(2, 'E')
             sage: E._init_attributes()
-
         """
         self._section_modules = {} # dict of section modules with domains as
                                    # keys
@@ -289,7 +287,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E = M.vector_bundle(2, 'E')
             sage: E.base_space()
             2-dimensional topological manifold M
-
         """
         return self._base_space
 
@@ -299,12 +296,11 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
 
         OUTPUT:
 
-        - a string describing the field, with three possible values:
+        A string describing the field, with three possible values:
 
-          - ``'real'`` for the real field `\RR`
-          - ``'complex'`` for the complex field `\CC`
-          - ``'neither_real_nor_complex'`` for a field different
-            from `\RR` and `\CC`
+        - ``'real'`` for the real field `\RR`
+        - ``'complex'`` for the complex field `\CC`
+        - ``'neither_real_nor_complex'`` for a field different from `\RR` and `\CC`
 
         EXAMPLES::
 
@@ -312,7 +308,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E = M.vector_bundle(2, 'E', field=CC)
             sage: E.base_field_type()
             'complex'
-
         """
         return self._field_type
 
@@ -320,9 +315,7 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
         r"""
         Return the field on which the fibers are defined.
 
-        OUTPUT:
-
-        - a topological field
+        OUTPUT: a topological field
 
         EXAMPLES::
 
@@ -330,7 +323,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E = M.vector_bundle(2, 'E', field=CC)
             sage: E.base_field()
             Complex Field with 53 bits of precision
-
         """
         return self._field
 
@@ -344,7 +336,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E = M.vector_bundle(3, 'E')
             sage: E.rank()
             3
-
         """
         return self._rank
 
@@ -359,7 +350,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E._repr_object_name()
             'real vector bundle E -> M of rank 1 over the base space
              2-dimensional topological manifold M'
-
         """
         desc = self.base_field_type() + " "
         desc += "vector bundle "
@@ -379,7 +369,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E._repr_()
             'Topological real vector bundle E -> M of rank 1 over the base space
              2-dimensional topological manifold M'
-
         """
         desc = "Topological "
         desc += self._repr_object_name()
@@ -395,7 +384,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E = M.vector_bundle(1, 'E')
             sage: E._latex_()
             'E\\to M'
-
         """
         latex = self._latex_name
         latex += r'\to '
@@ -418,7 +406,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E._add_local_frame(e)
             sage: E._frames
             [Local frame (E|_M, (e_0,e_1)), Local frame (E|_M, (e_0,e_1))]
-
         """
         self._trivial_parts.add(frame.domain())
         self._frames.append(frame)
@@ -447,20 +434,17 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E = M.vector_bundle(2, 'E')
             sage: phi = E.trivialization('phi', domain=U); phi
             Trivialization (phi, E|_U)
-
         """
         if domain is None:
             domain = self._base_space
-        from .trivialization import Trivialization
+        from sage.manifolds.trivialization import Trivialization
         return Trivialization(self, name, domain=domain, latex_name=latex_name)
 
     def transitions(self):
         r"""
         Return the transition maps defined over subsets of the base space.
 
-        OUTPUT:
-
-        - dictionary of transition maps, with pairs of trivializations as keys
+        OUTPUT: dictionary of transition maps, with pairs of trivializations as keys
 
         EXAMPLES::
 
@@ -480,7 +464,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
              (Trivialization (phi_U, E|_V),
              Trivialization (phi_U, E|_U)): Transition map from Trivialization
              (phi_U, E|_V) to Trivialization (phi_U, E|_U)}
-
         """
         return self._transitions.copy()
 
@@ -518,7 +501,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.transition(phi_V, phi_U)
             Transition map from Trivialization (phi_V, E|_V) to Trivialization
              (phi_U, E|_U)
-
         """
         if (triv1, triv2) not in self._transitions:
             raise TypeError("the transition map from " +
@@ -543,7 +525,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             [Trivialization (phi_U, E|_U),
              Trivialization (phi_V, E|_V),
              Trivialization (phi_M, E|_M)]
-
         """
         return list(self._atlas) # Make a (shallow) copy
 
@@ -569,7 +550,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             Trivialization (phi_M, E|_M)
             sage: E.is_manifestly_trivial()
             True
-
         """
         return self.base_space() in self._trivial_parts
 
@@ -584,7 +564,7 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
 
         - ``domain`` -- (default: ``None``) the domain on which the module is
           defined; if ``None`` the base space is assumed
-        - ``force_free`` -- (default: ``False``) if set to ``True``, force
+        - ``force_free`` -- boolean (default: ``False``); if set to ``True``, force
           the construction of a *free* module (this implies that `E` is trivial)
 
         OUTPUT:
@@ -655,12 +635,10 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
              manifold RP^1 with values in the real vector bundle E of rank 1
             sage: C0_U.an_element().display(phi_U.frame())
             2 (phi_U^*e_1)
-
         """
         if domain is None:
             domain = self._base_space
-        from sage.manifolds.section_module import (SectionModule,
-                                                   SectionFreeModule)
+        from sage.manifolds.section_module import SectionFreeModule, SectionModule
         if domain not in self._section_modules:
             if force_free or domain in self._trivial_parts:
                 self._section_modules[domain] = SectionFreeModule(self, domain)
@@ -694,7 +672,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
              3-dimensional topological manifold M
             sage: E.fiber(p)
             Fiber of E at Point p on the 3-dimensional topological manifold M
-
         """
         return VectorBundleFiber(self, point)
 
@@ -789,7 +766,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
 
             For more options, in particular for the choice of symbols and
             indices, see :class:`~sage.manifolds.local_frame.LocalFrame`.
-
         """
         from sage.manifolds.local_frame import LocalFrame
         # Input processing
@@ -864,7 +840,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: s = E.section(name='s'); s
             Section s on the 2-dimensional topological manifold M with values in the
              real vector bundle E of rank 2
-
         """
         domain = kwargs.pop('domain', self._base_space)
         name = kwargs.pop('name', None)
@@ -895,7 +870,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E = M.vector_bundle(2, 'E')
             sage: E.total_space()
             6-dimensional topological manifold E
-
         """
         if self._total_space is None:
             from sage.manifolds.manifold import Manifold
@@ -926,9 +900,10 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
           :class:`~sage.tensor.modules.free_module_automorphism.FreeModuleAutomorphism`
           describing the automorphism `P` that relates the basis `(e_i)` to
           the basis `(f_i)` according to `f_i = P(e_i)`
-        - ``compute_inverse`` (default: ``True``) -- if set to True, the inverse
-          automorphism is computed and the change from basis `(f_i)` to `(e_i)`
-          is set to it in the internal dictionary ``self._frame_changes``
+        - ``compute_inverse`` -- boolean (default: ``True``); if set to True,
+          the inverse automorphism is computed and the change from basis
+          `(f_i)` to `(e_i)` is set to it in the internal dictionary
+          ``self._frame_changes``
 
         EXAMPLES::
 
@@ -951,10 +926,8 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.change_of_frame(e,f)[e,:]
             [1 2]
             [0 3]
-
         """
-        from sage.tensor.modules.free_module_automorphism import \
-            FreeModuleAutomorphism
+        from sage.tensor.modules.free_module_automorphism import FreeModuleAutomorphism
         sec_module = frame1._fmodule
         if frame2._fmodule != sec_module:
             raise ValueError("the two frames are not defined on the same " +
@@ -1003,7 +976,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             True
             sage: a.inverse() == E.change_of_frame(f, e)
             True
-
         """
         if (frame1, frame2) not in self._frame_changes:
             raise ValueError("the change of frame from {} to {}".format(frame1, frame2) +
@@ -1043,7 +1015,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
              Local frame (E|_M, (f_0,f_1))): Automorphism of the Free module
              C^0(M;E) of sections on the 3-dimensional topological manifold M
              with values in the real vector bundle E of rank 2}
-
         """
         return self._frame_changes.copy()
 
@@ -1051,9 +1022,7 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
         r"""
         Return the list of local frames defined on ``self``.
 
-        OUTPUT:
-
-        - list of local frames defined on ``self``
+        OUTPUT: list of local frames defined on ``self``
 
         EXAMPLES::
 
@@ -1065,7 +1034,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.frames()
             [Trivialization frame (E|_U, ((phi_U^*e_1),(phi_U^*e_2))),
              Local frame (E|_V, (e_0,e_1))]
-
         """
         return list(self._frames)
 
@@ -1073,9 +1041,7 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
         r"""
         Return the list of coframes defined on ``self``.
 
-        OUTPUT:
-
-        - list of coframes defined on ``self``
+        OUTPUT: list of coframes defined on ``self``
 
         EXAMPLES::
 
@@ -1087,7 +1053,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.coframes()
             [Trivialization coframe (E|_U, ((phi_U^*e^1),(phi_U^*e^2))),
              Local coframe (E|_V, (e^0,e^1))]
-
         """
         return list(self._coframes)
 
@@ -1107,7 +1072,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: e = E.local_frame('e')
             sage: E.default_frame()
             Local frame (E|_M, (e_0,e_1))
-
         """
         return self._def_frame
 
@@ -1131,7 +1095,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.set_default_frame(f)
             sage: E.default_frame()
             Local frame (E|_M, (f_0,f_1))
-
         """
         from sage.manifolds.local_frame import LocalFrame
         if not isinstance(frame, LocalFrame):
@@ -1188,9 +1151,8 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.orientation()
             [Local frame (E|_U, (e_0,e_1)),
              Local frame (E|_V, (f_0,f_1))]
-
         """
-        from .local_frame import LocalFrame
+        from sage.manifolds.local_frame import LocalFrame
         if isinstance(orientation, LocalFrame):
             orientation = [orientation]
         elif isinstance(orientation, (tuple, list)):
@@ -1268,7 +1230,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.orientation()
             [Local frame (E|_U, (e_0,e_1)),
              Local frame (E|_V, (f_0,f_1))]
-
         """
         if not self._orientation:
             # Trivial case:
@@ -1324,7 +1285,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
             sage: E.set_orientation([e, f])
             sage: E.has_orientation()
             True
-
         """
         return bool(self.orientation())
 
@@ -1369,7 +1329,6 @@ class TopologicalVectorBundle(CategoryObject, UniqueRepresentation):
 
             sage: next(E.irange()) == M.start_index()
             True
-
         """
         si = self._base_space._sindex
         imax = self._rank + si
