@@ -64,12 +64,22 @@ In contrast, input to the ``%time`` magic command is preparsed::
     sage: shell.quit()
 """
 
-from IPython.core.magic import Magics, magics_class, line_magic, cell_magic
+from IPython.core.display import HTML
+from IPython.core.getipython import get_ipython
+from IPython.core.magic import Magics, cell_magic, line_magic, magics_class
 
-from sage.repl.load import load_wrap
 from sage.env import SAGE_IMPORTALL, SAGE_STARTUP_FILE
 from sage.misc.lazy_import import LazyImport
 from sage.misc.misc import run_once
+from sage.repl.load import load_wrap
+
+
+def _running_in_notebook():
+    try:
+        from ipykernel.zmqshell import ZMQInteractiveShell
+    except ImportError:
+        return False
+    return isinstance(get_ipython(), ZMQInteractiveShell)
 
 
 @magics_class
@@ -107,6 +117,10 @@ class SageMagics(Magics):
 
         - ``s`` -- string; the file to be loaded
 
+        .. SEEALSO::
+
+            This is the same as :func:`~sage.repl.load.load`.
+
         EXAMPLES::
 
             sage: import os
@@ -133,6 +147,10 @@ class SageMagics(Magics):
 
         - ``s`` -- string. The file to be attached
 
+        .. SEEALSO::
+
+            This is the same as :func:`~sage.repl.attach.attach`.
+
         EXAMPLES::
 
             sage: from sage.repl.interpreter import get_test_shell
@@ -302,8 +320,8 @@ class SageMagics(Magics):
                 max_width = 0
             if max_width <= 0:
                 raise ValueError(
-                        "max width must be a positive integer")
-            import sage.typeset.character_art as character_art
+                    "max width must be a positive integer")
+            from sage.typeset import character_art
             character_art.MAX_WIDTH = max_width
             dm.preferences.text = arg0
         # Unset all
@@ -340,9 +358,34 @@ class SageMagics(Magics):
         This is syntactic sugar on the
         :func:`~sage.misc.cython.cython_compile` function.
 
+        Note that there is also the ``%%cython`` cell magic provided by Cython,
+        which can be loaded with ``%load_ext cython``, see
+        `Cython documentation <https://cython.readthedocs.io/en/latest/src/userguide/source_files_and_compilation.html#compiling-with-a-jupyter-notebook>`_
+        for more details.
+        The semantic is slightly different from the version provided by Sage.
+
         INPUT:
 
-        - ``line`` -- ignored
+        - ``line`` -- parsed as keyword arguments. The allowed arguments are:
+
+          - ``--verbose N`` / ``-v N``
+          - ``--compile-message``
+          - ``--use-cache``
+          - ``--create-local-c-file``
+          - ``--annotate``
+          - ``--view-annotate``
+          - ``--sage-namespace``
+          - ``--create-local-so-file``
+          - ``--no-compile-message``, ``--no-use-cache``, etc.
+
+          See :func:`~sage.misc.cython.cython` for details.
+
+          If ``--view-annotate`` is given, the annotation is either displayed
+          inline in the Sage notebook or opened in a new web browser, depending
+          on whether the Sage notebook is used.
+
+          You can override the selection by specifying
+          ``--view-annotate=webbrowser`` or ``--view-annotate=displayhtml``.
 
         - ``cell`` -- string; the Cython source code to process
 
@@ -350,19 +393,131 @@ class SageMagics(Magics):
 
         EXAMPLES::
 
+            sage: # needs sage.misc.cython
             sage: from sage.repl.interpreter import get_test_shell
             sage: shell = get_test_shell()
-            sage: shell.run_cell(                                                       # needs sage.misc.cython
+            sage: shell.run_cell(
             ....: '''
-            ....: %%cython
+            ....: %%cython -v1 --annotate --no-sage-namespace
             ....: def f():
             ....:     print('test')
             ....: ''')
-            sage: f()                                                                   # needs sage.misc.cython
+            Compiling ....pyx because it changed.
+            [1/1] Cythonizing ....pyx
+            sage: f()
             test
+
+        TESTS:
+
+        Test unrecognized arguments::
+
+            sage: # needs sage.misc.cython
+            sage: shell.run_cell('''
+            ....: %%cython --some-unrecognized-argument
+            ....: print(1)
+            ....: ''')
+            UsageError: unrecognized arguments: --some-unrecognized-argument
+
+        Test ``--help`` is disabled::
+
+            sage: # needs sage.misc.cython
+            sage: shell.run_cell('''
+            ....: %%cython --help
+            ....: print(1)
+            ....: ''')
+            UsageError: unrecognized arguments: --help
+
+        Test ``--view-annotate`` invalid arguments::
+
+            sage: # needs sage.misc.cython
+            sage: shell.run_cell('''
+            ....: %%cython --view-annotate=xx
+            ....: print(1)
+            ....: ''')  # exact error message differ between Python 3.11/3.13
+            UsageError: argument --view-annotate: invalid choice: 'xx' (choose from ...)
+
+        Test ``--view-annotate=displayhtml`` (note that in a notebook environment
+        an inline HTML frame will be displayed)::
+
+            sage: # needs sage.misc.cython
+            sage: shell.run_cell('''
+            ....: %%cython --view-annotate=displayhtml
+            ....: print(1)
+            ....: ''')
+            1
+            <IPython.core.display.HTML object>
+
+        Test ``--view-annotate=webbrowser``::
+
+            sage: # needs sage.misc.cython webbrowser
+            sage: shell.run_cell('''
+            ....: %%cython --view-annotate
+            ....: print(1)
+            ....: ''')
+            1
+            sage: shell.run_cell('''
+            ....: %%cython --view-annotate=auto
+            ....: print(1)
+            ....: ''')  # --view-annotate=auto is undocumented feature, equivalent to --view-annotate
+            1
+            sage: shell.run_cell('''
+            ....: %%cython --view-annotate=webbrowser
+            ....: print(1)
+            ....: ''')
+            1
+
+        Test invalid quotes::
+
+            sage: # needs sage.misc.cython
+            sage: shell.run_cell('''
+            ....: %%cython --a='
+            ....: print(1)
+            ....: ''')
+            ...
+            ValueError...Traceback (most recent call last)
+            ...
+            ValueError: No closing quotation
         """
+        import argparse
+        import shlex
+
         from sage.misc.cython import cython_compile
-        return cython_compile(cell)
+
+        class ExitCatchingArgumentParser(argparse.ArgumentParser):
+            def error(self, message):
+                # exit_on_error=False does not work completely in some Python versions
+                # see https://stackoverflow.com/q/67890157
+                # we raise UsageError to make the interface similar to what happens when e.g.
+                # IPython's ``%run`` gets unrecognized arguments
+                from IPython.core.error import UsageError
+                raise UsageError(message)
+
+        parser = ExitCatchingArgumentParser(prog="%%cython", add_help=False)
+        parser.add_argument("--verbose", "-v", type=int)
+        parser.add_argument("--compile-message", action=argparse.BooleanOptionalAction)
+        parser.add_argument("--use-cache", action=argparse.BooleanOptionalAction)
+        parser.add_argument("--create-local-c-file", action=argparse.BooleanOptionalAction)
+        parser.add_argument("--annotate", action=argparse.BooleanOptionalAction)
+        parser.add_argument("--view-annotate", choices=["none", "auto", "webbrowser", "displayhtml"],
+                            nargs="?", const="auto", default="none")
+        parser.add_argument("--sage-namespace", action=argparse.BooleanOptionalAction)
+        parser.add_argument("--create-local-so-file", action=argparse.BooleanOptionalAction)
+        args = parser.parse_args(shlex.split(line))
+        view_annotate = args.view_annotate
+        del args.view_annotate
+        if view_annotate == "auto":
+            if _running_in_notebook():
+                view_annotate = "displayhtml"
+            else:
+                view_annotate = "webbrowser"
+        args_dict = {k: v for k, v in args.__dict__.items() if v is not None}
+        if view_annotate != "none":
+            args_dict["view_annotate"] = True
+            if view_annotate == "displayhtml":
+                path_to_annotate_html_container = []
+                cython_compile(cell, **args_dict, view_annotate_callback=path_to_annotate_html_container.append)
+                return HTML(filename=path_to_annotate_html_container[0])
+        return cython_compile(cell, **args_dict)
 
     @cell_magic
     def fortran(self, line, cell):
@@ -434,10 +589,7 @@ class SageCustomizations:
         self.init_inspector()
         self.init_line_transforms()
 
-        try:
-            import sage.all # until sage's import hell is fixed
-        except ImportError:
-            import sage.all__sagemath_repl
+        import sage.all  # noqa: F401
 
         self.shell.verbose_quit = True
 
@@ -509,12 +661,13 @@ class SageCustomizations:
 
         Check that :issue:`31951` is fixed::
 
+             sage: # indirect doctest
              sage: from IPython import get_ipython
              sage: ip = get_ipython()
-             sage: ip.input_transformer_manager.check_complete('''  # indirect doctest
+             sage: ip.input_transformer_manager.check_complete('''
              ....: for i in [1 .. 2]:
              ....:     a = 2''')
-             ('incomplete', 2)
+             ('incomplete', 4)
              sage: ip.input_transformer_manager.check_complete('''
              ....: def foo(L)
              ....:     K.<a> = L''')
@@ -550,7 +703,8 @@ class SageCustomizations:
              ('incomplete', 4)
         """
         from IPython.core.inputtransformer2 import TransformerManager
-        from .interpreter import SagePromptTransformer, SagePreparseTransformer
+
+        from sage.repl.interpreter import SagePreparseTransformer, SagePromptTransformer
 
         self.shell.input_transformer_manager.cleanup_transforms.insert(1, SagePromptTransformer)
         self.shell.input_transformers_post.append(SagePreparseTransformer)
