@@ -723,7 +723,7 @@ class FunctionFieldIdeal_module(FunctionFieldIdeal, Ideal_generic):
         """
         return self._module
 
-    def gens(self):
+    def gens(self) -> tuple:
         """
         Return a set of generators of this ideal.
 
@@ -1066,7 +1066,7 @@ class IdealMonoid(UniqueRepresentation, Parent):
             sage: M = O.ideal_monoid()
             sage: TestSuite(M).run()
         """
-        self.Element = R._ideal_class
+        self.Element = R._ideal_class_
         Parent.__init__(self, category=Monoids())
 
         self.__R = R
