@@ -70,6 +70,7 @@ class CappedAbsoluteGeneric(LocalGeneric):
         """
         return 'capped-abs'
 
+
 class CappedRelativeGeneric(LocalGeneric):
     def is_capped_relative(self):
         """
@@ -107,6 +108,7 @@ class CappedRelativeGeneric(LocalGeneric):
         """
         return 'capped-rel'
 
+
 class FixedModGeneric(LocalGeneric):
     def is_fixed_mod(self):
         """
@@ -145,6 +147,7 @@ class FixedModGeneric(LocalGeneric):
         """
         return 'fixed-mod'
 
+
 class FloatingPointGeneric(LocalGeneric):
     def is_floating_point(self):
         """
@@ -186,7 +189,7 @@ class FloatingPointGeneric(LocalGeneric):
         Test the distributivity of `*` on `+` on (not necessarily
         all) elements of this set.
 
-        p-adic floating point rings only satisfy distributivity
+        `p`-adic floating point rings only satisfy distributivity
         up to a precision that depends on the elements.
 
         INPUT:
@@ -254,18 +257,28 @@ class FloatingPointGeneric(LocalGeneric):
         tester = self._tester(**options)
         S = tester.some_elements()
         from sage.misc.misc import some_tuples
-        for x,y,z in some_tuples(S, 3, tester._max_runs):
+        for x, y, z in some_tuples(S, 3, tester._max_runs):
             tester.assertTrue(((x + y) + z).is_equal_to(x + (y + z), min(x.precision_absolute(), y.precision_absolute(), z.precision_absolute())))
 
+
 class FloatingPointRingGeneric(FloatingPointGeneric):
     pass
-class FloatingPointFieldGeneric(FloatingPointGeneric):#, sage.rings.ring.Field):
+
+
+class FloatingPointFieldGeneric(FloatingPointGeneric):
+    # in category of Fields()
     pass
+
+
 class CappedRelativeRingGeneric(CappedRelativeGeneric):
     pass
-class CappedRelativeFieldGeneric(CappedRelativeGeneric):#, sage.rings.ring.Field):
+
+
+class CappedRelativeFieldGeneric(CappedRelativeGeneric):
+    # in category of Fields()
     pass
 
+
 class pAdicLatticeGeneric(pAdicGeneric):
     r"""
     An implementation of the `p`-adic rationals with lattice precision.
@@ -276,10 +289,10 @@ class pAdicLatticeGeneric(pAdicGeneric):
 
     - ``prec`` -- the precision
 
-    - ``subtype`` -- either ``"cap"`` or ``"float"``,
+    - ``subtype`` -- either ``'cap'`` or ``'float'``,
       specifying the precision model used for tracking precision
 
-    - ``label`` -- a string or ``None`` (default: ``None``)
+    - ``label`` -- string or ``None`` (default: ``None``)
 
     TESTS::
 
@@ -301,7 +314,7 @@ class pAdicLatticeGeneric(pAdicGeneric):
         sage: R._prec_type()
         'lattice-float'
     """
-    def __init__(self, p, prec, print_mode, names, label=None):
+    def __init__(self, p, prec, print_mode, names, label=None, category=None):
         """
         Initialization.
 
@@ -344,7 +357,7 @@ class pAdicLatticeGeneric(pAdicGeneric):
         else:
             raise ValueError("subtype must be either 'cap' or 'float'")
         self._element_class = self.__make_element_class__(element_class)
-        pAdicGeneric.__init__(self, self, p, prec, print_mode, names, None)
+        pAdicGeneric.__init__(self, self, p, prec, print_mode, names, None, category=category)
 
     def _prec_type(self):
         """
@@ -546,9 +559,9 @@ class pAdicLatticeGeneric(pAdicGeneric):
 
         INPUT:
 
-        - ``x``: the datum from which the element is created
+        - ``x`` -- the datum from which the element is created
 
-        - ``prec`` -- an integer or ``None`` (the default); the
+        - ``prec`` -- integer or ``None`` (the default); the
           absolute precision of the created element
 
         NOTE:
@@ -721,7 +734,7 @@ class pAdicRelaxedGeneric(pAdicGeneric):
 
         INPUT:
 
-        - ``name`` -- a string or ``None`` (default: ``None``); if ``None``,
+        - ``name`` -- string or ``None`` (default: ``None``); if ``None``,
           return the generic class from which all the others derive
 
         TESTS::
@@ -813,12 +826,12 @@ class pAdicRelaxedGeneric(pAdicGeneric):
         EXAMPLES::
 
             sage: # needs sage.libs.flint
-            sage: R = ZpER(5, print_mode="digits")
+            sage: R = ZpER(5, print_mode='digits')
             sage: R.default_prec()
             20
             sage: R(1/17)
             ...34024323104201213403
-            sage: S = ZpER(5, prec=10, print_mode="digits")
+            sage: S = ZpER(5, prec=10, print_mode='digits')
             sage: S.default_prec()
             10
             sage: S(1/17)
@@ -837,7 +850,7 @@ class pAdicRelaxedGeneric(pAdicGeneric):
 
         EXAMPLES::
 
-            sage: R = ZpER(5, print_mode="digits")                                      # needs sage.libs.flint
+            sage: R = ZpER(5, print_mode='digits')                                      # needs sage.libs.flint
             sage: R.halting_prec()                                                      # needs sage.libs.flint
             40
         """
@@ -881,7 +894,7 @@ class pAdicRelaxedGeneric(pAdicGeneric):
 
         - ``x`` -- the datum from which the element is created
 
-        - ``prec`` -- an integer or ``None`` (default: ``None``);
+        - ``prec`` -- integer or ``None`` (default: ``None``);
           if given, bound the precision of the element to ``prec``
 
         EXAMPLES::
@@ -1012,10 +1025,10 @@ class pAdicRelaxedGeneric(pAdicGeneric):
 
         INPUT:
 
-        - ``start_val`` -- an integer (default: 0); a lower bound on the
+        - ``start_val`` -- integer (default: 0); a lower bound on the
           valuation of the returned element
 
-        - ``digits`` -- an element, a list or ``None`` (default: ``None``);
+        - ``digits`` -- an element, a list, or ``None`` (default: ``None``);
           the first digit or the list of the digits of the returned element
 
         NOTE:
@@ -1111,10 +1124,10 @@ class pAdicRelaxedGeneric(pAdicGeneric):
 
         INPUT:
 
-        - ``integral`` -- a boolean (default: ``False``); if ``True``,
+        - ``integral`` -- boolean (default: ``False``); if ``True``,
           return a random element in the ring of integers of this ring
 
-        - ``prec`` -- an integer or ``None`` (default: ``None``);
+        - ``prec`` -- integer or ``None`` (default: ``None``);
           if given, bound the precision of the output to ``prec``
 
         EXAMPLES::
@@ -1149,7 +1162,7 @@ class pAdicRelaxedGeneric(pAdicGeneric):
 
         EXAMPLES::
 
-            sage: R = ZpER(5, print_mode="digits")                                      # needs sage.libs.flint
+            sage: R = ZpER(5, print_mode='digits')                                      # needs sage.libs.flint
             sage: R.teichmuller(2)                                                      # needs sage.libs.flint
             ...40423140223032431212
         """
@@ -1165,7 +1178,7 @@ class pAdicRelaxedGeneric(pAdicGeneric):
 
         EXAMPLES::
 
-            sage: R = ZpER(7, print_mode="digits")                                      # needs sage.libs.flint
+            sage: R = ZpER(7, print_mode='digits')                                      # needs sage.libs.flint
             sage: R.teichmuller_system()                                                # needs sage.libs.flint
             [...00000000000000000001,
              ...16412125443426203642,
@@ -1192,16 +1205,14 @@ class pAdicRingGeneric(pAdicGeneric, sage.rings.abc.pAdicRing):
 
     def krull_dimension(self):
         r"""
-        Return the Krull dimension of self, i.e. 1
+        Return the Krull dimension of self, i.e. 1.
 
         INPUT:
 
-        - self -- a `p`-adic ring
+        - ``self`` -- a `p`-adic ring
 
-        OUTPUT:
-
-        - the Krull dimension of self.  Since self is a `p`-adic ring,
-          this is 1.
+        OUTPUT: the Krull dimension of ``self``.  Since ``self`` is a `p`-adic
+        ring, this is 1.
 
         EXAMPLES::
 
@@ -1218,12 +1229,12 @@ class pAdicRingGeneric(pAdicGeneric, sage.rings.abc.pAdicRing):
 
         INPUT:
 
-         - ``f``, ``g`` -- the polynomials of which to take the xgcd
+        - ``f``, ``g`` -- the polynomials of which to take the xgcd
 
         OUTPUT:
 
-         - A tuple (a, b, c) which satisfies ``a = b*f + c*g``. There
-           is no guarantee that a, b, and c are minimal.
+        A tuple (a, b, c) which satisfies a = b*f + c*g. There
+        is no guarantee that a, b, and c are minimal.
 
         .. WARNING::
 
@@ -1291,9 +1302,9 @@ class pAdicRingGeneric(pAdicGeneric, sage.rings.abc.pAdicRing):
 
         INPUT:
 
-         - ``f``, ``g`` -- the polynomials of which to take the gcd
+        - ``f``, ``g`` -- the polynomials of which to take the gcd
 
-        OUTPUT: A polynomial
+        OUTPUT: a polynomial
 
         EXAMPLES::
 
@@ -1341,19 +1352,31 @@ class pAdicFieldGeneric(pAdicGeneric, sage.rings.abc.pAdicField):
     #def subfields_of_degree(self, n):
     #    raise NotImplementedError
 
+
 class pAdicFixedModRingGeneric(pAdicRingGeneric, FixedModGeneric):
     pass
+
+
 class pAdicCappedAbsoluteRingGeneric(pAdicRingGeneric, CappedAbsoluteGeneric):
     pass
+
+
 class pAdicCappedRelativeRingGeneric(pAdicRingGeneric, CappedRelativeRingGeneric):
     pass
+
+
 class pAdicCappedRelativeFieldGeneric(pAdicFieldGeneric, CappedRelativeFieldGeneric):
     pass
+
+
 class pAdicFloatingPointRingGeneric(pAdicRingGeneric, FloatingPointRingGeneric):
     pass
+
+
 class pAdicFloatingPointFieldGeneric(pAdicFieldGeneric, FloatingPointFieldGeneric):
     pass
 
+
 class pAdicRingBaseGeneric(pAdicBaseGeneric, pAdicRingGeneric):
     def construction(self, forbid_frac_field=False):
         """
@@ -1365,7 +1388,7 @@ class pAdicRingBaseGeneric(pAdicBaseGeneric, pAdicRingGeneric):
 
         INPUT:
 
-        - ``forbid_frac_field`` -- ignored, for compatibility with other p-adic types.
+        - ``forbid_frac_field`` -- ignored, for compatibility with other `p`-adic types
 
         EXAMPLES::
 
@@ -1445,6 +1468,7 @@ class pAdicRingBaseGeneric(pAdicBaseGeneric, pAdicRingGeneric):
     #def principal_unit_group(self):
     #    raise NotImplementedError
 
+
 class pAdicFieldBaseGeneric(pAdicBaseGeneric, pAdicFieldGeneric):
     def composite(self, subfield1, subfield2):
         r"""
@@ -1457,9 +1481,7 @@ class pAdicFieldBaseGeneric(pAdicBaseGeneric, pAdicFieldGeneric):
         - ``subfield1`` -- a subfield
         - ``subfield2`` -- a subfield
 
-        OUTPUT:
-
-        the composite of ``subfield1`` and ``subfield2``
+        OUTPUT: the composite of ``subfield1`` and ``subfield2``
 
         EXAMPLES::
 
@@ -1473,12 +1495,12 @@ class pAdicFieldBaseGeneric(pAdicBaseGeneric, pAdicFieldGeneric):
 
     def subfields_of_degree(self, n):
         r"""
-        Return the number of subfields of ``self`` of degree `n`
+        Return the number of subfields of ``self`` of degree `n`.
 
         INPUT:
 
         - ``self`` -- a `p`-adic field
-        - ``n`` -- an integer
+        - ``n`` -- integer
 
         OUTPUT:
 
@@ -1497,16 +1519,14 @@ class pAdicFieldBaseGeneric(pAdicBaseGeneric, pAdicFieldGeneric):
 
     def subfield(self, list):
         r"""
-        Return the subfield generated by the elements in ``list``
+        Return the subfield generated by the elements in ``list``.
 
         INPUT:
 
         - ``self`` -- a `p`-adic field
-        - ``list`` -- a list of elements of ``self``
+        - ``list`` -- list of elements of ``self``
 
-        OUTPUT:
-
-        the subfield of ``self`` generated by the elements of ``list``
+        OUTPUT: the subfield of ``self`` generated by the elements of ``list``
 
         EXAMPLES::
 
