@@ -236,14 +236,14 @@ def LaurentPolynomialRing(base_ring, *args, **kwds):
            sage: (w0 + 2*w8 + w13)^2                                                    # needs sage.modules
            w0^2 + 4*w0*w8 + 4*w8^2 + 2*w0*w13 + 4*w8*w13 + w13^2
     """
-    from sage.rings.polynomial.polynomial_ring import PolynomialRing_general
+    from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
     from sage.rings.polynomial.multi_polynomial_ring_base import MPolynomialRing_base
 
     R = PolynomialRing(base_ring, *args, **kwds)
     if R in _cache:
         return _cache[R]   # put () here to re-enable weakrefs
 
-    if isinstance(R, PolynomialRing_general):
+    if isinstance(R, PolynomialRing_generic):
         # univariate case
         P = LaurentPolynomialRing_univariate(R)
     else:
